@@ -163,7 +163,10 @@ class Dos:
                 if self.sp_method == 'absolute':
                     self.tdos_array[:,1] = self.pdos_array.sum(axis=1).sum(axis=1)
                 elif self.sp_method == 'percentage':
-                    self.tdos_array[:,1] = (self.pdos_array[0].sum(axis=1).sum(axis=1) - self.pdos_array[1].sum(axis=1).sum(axis=1)) / (self.pdos_array[0].sum(axis=1).sum(axis=1) + self.pdos_array[1].sum(axis=1).sum(axis=1))
+                    if self.combination_method == 'add':
+                        raise BaseException("If using combination_method='add' and spin orbit coupling is applied, just set spin='up'")
+                    else:
+                        self.tdos_array[:,1] = (self.pdos_array[0].sum(axis=1).sum(axis=1) - self.pdos_array[1].sum(axis=1).sum(axis=1)) / (self.pdos_array[0].sum(axis=1).sum(axis=1) + self.pdos_array[1].sum(axis=1).sum(axis=1))
 
 
     def _check_f_orb(self):
@@ -1003,7 +1006,7 @@ class Dos:
                     )
 
 
-    def plot_plain(self, ax, linewidth=1.5, fill=True, alpha=0.3, alpha_line=1.0, sigma=0.05, energyaxis='y', color='black', erange=[-6, 6]):
+    def plot_plain(self, ax, linewidth=1.5, fill=True, alpha=0.3, alpha_line=1.0, sigma=0.05, energyaxis='y', color='black', erange=[-6, 6], log_scale=False):
         """
         This function plots the total density of states
 
@@ -1033,6 +1036,12 @@ class Dos:
         else:
             tdensity = tdos_array[:,1]
 
+        if log_scale:
+            tdensity = np.log10(tdensity)
+            neg_inf_loc = np.isin(tdensity, -np.inf)
+            min_val = np.min(tdensity[np.logical_not(neg_inf_loc)])
+            tdensity[neg_inf_loc] = min_val
+
         self._set_density_lims(
             ax=ax,
             tdensity=tdensity,
@@ -1040,6 +1049,7 @@ class Dos:
             erange=erange,
             energyaxis=energyaxis,
             spin=self.spin,
+            log_scale=log_scale,
         )
 
         if energyaxis == 'y':
