@@ -119,7 +119,13 @@ def generate_kpoints(M, high_symmetry_points, n, output='KPOINTS'):
     save2VaspKPOINTS(reducedK, output)
 
 
-def get_bandgap(folder, printbg=True, return_vbm_cbm=False):
+def get_bandgap(
+    folder,
+    printbg=True,
+    return_vbm_cbm=False,
+    spin='both',
+    method=0,
+):
     """
     Determines the band gap from a band structure calculation
 
@@ -127,24 +133,29 @@ def get_bandgap(folder, printbg=True, return_vbm_cbm=False):
         folder (str): Folder that contains the VASP input and outputs files
         printbg (bool): Determines if the band gap value is printed out or not.
         return_vbm_cbm (bool): Determines if the vbm and cbm are returned.
+        spin (str): 'both' returns the bandgap for all spins, 'up' returns the 
+            bandgap for only the spin up states and 'down' returns the bandgap
+            for only the spin down states.
+        method (int): method=0 gets the band gap by finding the values closest to
+            the fermi level. method=1 gets the band gap based on the average energy
+            of each band.
 
     Returns:
         if return_vbm_cbm is False: The band gap is returned in eV
         if return_vbm_cbm is True: The band gap, vbm, and cbm are returned in eV in that order
     """
-    def _get_bandgap(eigenvalues, printbg=printbg):
+    def _get_bandgap_0(eigenvalues, printbg=printbg):
+
+        occupied = eigenvalues[np.where(eigenvalues[:,:,0] < 0)]
+        unoccupied = eigenvalues[np.where(eigenvalues[:,:,0] > 0)]
+
+        vbm = np.max(occupied[:,0])
+        cbm = np.min(unoccupied[:,0])
+
         if np.sum(np.diff(np.sign(eigenvalues[:,:,0])) != 0) == 0:
-            occupied = eigenvalues[np.where(eigenvalues[:,:,0] < 0)]
-            unoccupied = eigenvalues[np.where(eigenvalues[:,:,0] > 0)]
-
-            vbm = np.max(occupied[:,0])
-            cbm = np.min(unoccupied[:,0])
-
             bg = cbm - vbm
         else:
             bg = 0
-            vbm = np.nan
-            cbm = np.nan
 
         if printbg:
             print(f'Bandgap = {np.round(bg, 3)} eV')
@@ -157,6 +168,33 @@ def get_bandgap(folder, printbg=True, return_vbm_cbm=False):
         else:
             return bg
 
+    def _get_bandgap_1(eigenvalues, printbg=printbg):
+        band_mean = eigenvalues[:,:,0].mean(axis=1)
+
+        below_index = np.where(band_mean < 0)[0]
+        above_index = np.where(band_mean >= 0)[0]
+
+        vbm = np.max(eigenvalues[below_index, :, 0])
+        cbm = np.min(eigenvalues[above_index, :, 0])
+
+        if np.sum(np.diff(np.sign(eigenvalues[:,:,0])) != 0) == 0:
+            bg = cbm - vbm
+        else:
+            bg = 0
+
+        if printbg:
+            print(f'Bandgap = {np.round(bg, 3)} eV')
+            if return_vbm_cbm:
+                print(f'VBM = {np.round(vbm, 3)} eV')
+                print(f'CBM = {np.round(cbm, 3)} eV')
+
+        if return_vbm_cbm:
+            return bg, vbm, cbm
+        else:
+            return bg
+        
+
+
     pre_loaded_bands = os.path.isfile(os.path.join(folder, 'eigenvalues.npy'))
     eigenval = Eigenval(os.path.join(folder, 'EIGENVAL'))
     efermi = float(os.popen(f'grep E-fermi {os.path.join(folder, "OUTCAR")}').read().split()[2])
@@ -196,13 +234,22 @@ def get_bandgap(folder, printbg=True, return_vbm_cbm=False):
             kpoints = band_data[0,:,4:]
             eigenvalues_up = band_data[:,:,[0,1]]
             eigenvalues_down = band_data[:,:,[2,3]]
-            eigenvalues_bg = np.vstack([eigenvalues_up, eigenvalues_down])
+            if spin == 'both':
+                eigenvalues_bg = np.vstack([eigenvalues_up, eigenvalues_down])
+            elif spin == 'up':
+                eigenvalues_bg = eigenvalues_up
+            elif spin == 'down':
+                eigenvalues_bg = eigenvalues_down
         else:
             eigenvalues = band_data[:,:,0]
             kpoints = band_data[0,:,2:]
             eigenvalues_bg = band_data[:,:,[0,1]]
         
-        band_gap = _get_bandgap(eigenvalues=eigenvalues_bg)
+        if method == 0:
+            band_gap = _get_bandgap_0(eigenvalues=eigenvalues_bg)
+        elif method == 1:
+            band_gap = _get_bandgap_1(eigenvalues=eigenvalues_bg)
+
     else:
         if len(eigenval.eigenvalues.keys()) > 1:
             eigenvalues_up = np.transpose(eigenval.eigenvalues[Spin.up], axes=(1,0,2))
@@ -213,7 +260,12 @@ def get_bandgap(folder, printbg=True, return_vbm_cbm=False):
                 [eigenvalues_up, eigenvalues_down],
                 axis=2
             )
-            eigenvalues_bg = np.vstack([eigenvalues_up, eigenvalues_down])
+            if spin == 'both':
+                eigenvalues_bg = np.vstack([eigenvalues_up, eigenvalues_down])
+            elif spin == 'up':
+                eigenvalues_bg = eigenvalues_up
+            elif spin == 'down':
+                eigenvalues_bg = eigenvalues_down
         else:
             eigenvalues = np.transpose(eigenval.eigenvalues[Spin.up], axes=(1,0,2))
             eigenvalues[:,:,0] = eigenvalues[:,:,0] - efermi
@@ -228,7 +280,10 @@ def get_bandgap(folder, printbg=True, return_vbm_cbm=False):
             eigenvalues_bg = eigenvalues_bg[:, zero_weight]
             kpoints = kpoints[zero_weight]
 
-        band_gap = _get_bandgap(eigenvalues=eigenvalues_bg)
+        if method == 0:
+            band_gap = _get_bandgap_0(eigenvalues=eigenvalues_bg)
+        elif method == 1:
+            band_gap = _get_bandgap_1(eigenvalues=eigenvalues_bg)
 
         band_data = np.append(
             eigenvalues,
@@ -432,6 +487,7 @@ def get_periodic_vacuum(
         vacuum=40,
         write_file=False,
         output='POSCAR_good_vacuum',
+        periodic_vacuum=True,
 ):
     """
     Creates a slab with a vacuum that is an integer multiple of unit cell length in the direction of the
@@ -478,7 +534,12 @@ def get_periodic_vacuum(
     slab_height_in_unit_cells = np.round(((max_z2 - min_z2) * c_len) / unit_cell_len, 0)
     vacuum_height_in_unit_cells = np.round(vacuum / unit_cell_len, 0)
     new_lattice = copy.deepcopy(slab.lattice.matrix)
-    new_lattice[-1] = (new_lattice[-1] / np.linalg.norm(new_lattice[-1])) * (slab_height_in_unit_cells + vacuum_height_in_unit_cells) * unit_cell_len
+
+    if periodic_vacuum:
+        new_lattice[-1] = (new_lattice[-1] / np.linalg.norm(new_lattice[-1])) * (slab_height_in_unit_cells + vacuum_height_in_unit_cells) * unit_cell_len
+    else:
+        new_lattice[-1] = (new_lattice[-1] / np.linalg.norm(new_lattice[-1])) * (((max_z2 - min_z2) * c_len) + vacuum)
+
     new_c_len = np.linalg.norm(new_lattice[-1])
     new_frac_coords = copy.deepcopy(slab.frac_coords)
     new_frac_coords[:,-1] = new_frac_coords[:,-1] * (c_len / new_c_len)
@@ -530,6 +591,7 @@ def generate_slab(
         passivate_bot=True,
         symmetrize=False,
         tol=0.0001,
+        periodic_vacuum=True,
 ):
     """
     This function generates a slab structure.
@@ -564,7 +626,7 @@ def generate_slab(
         bulk_structure_ase,
         miller_index,
         layers,
-        vacuum=vacuum,
+        vacuum=40,
         periodic=False
     )
     sorted_slab = sort(ase_slab, tags=ase_slab.positions[:,-1])
@@ -577,11 +639,12 @@ def generate_slab(
         bulk_structure_prim,
         miller_index,
         vacuum=vacuum,
+        periodic_vacuum=periodic_vacuum,
     )
 
     if passivate:
         if passivated_file is not None:
-            passivated_file = Poscar.from_file(passivated_file).structure
+            passivated_file = Structure.from_file(passivated_file)
 
         slab_primitive = passivator(
             slab_primitive,
@@ -756,13 +819,6 @@ if __name__ == "__main__":
         #  slab_folder='../../vaspvis_data/slabdos',
         #  atoms=[17,50],
     #  )
-    slab = generate_slab(
-        bulk='../../../../projects/unfold_test/POSCAR_InSb_conv',
-        miller_index=[1,1,0],
-        layers=8,
-        vacuum=30,
-        passivate=True,
-    )
     #  slab = passivator(
         #  struc=Poscar.from_file('./POSCAR_0').structure,
         #  write_file=True,
@@ -791,3 +847,18 @@ if __name__ == "__main__":
         #  vacuum=40,
         #  write_file=True
     #  )
+    bg = get_bandgap(
+        folder='/home/derek/for_James/band/',
+        return_vbm_cbm=True,
+        printbg=True,
+        method=0,
+        spin='up',
+    )
+    bg = get_bandgap(
+        folder='/home/derek/for_James/band/',
+        return_vbm_cbm=True,
+        printbg=True,
+        method=0,
+        spin='down',
+    )
+    #  print(bg)
